Index: trunk/src/uvmat.m
===================================================================
--- trunk/src/uvmat.m	(revision 589)
+++ trunk/src/uvmat.m	(revision 591)
@@ -34,5 +34,5 @@
 %                       .PosSetObject: position of set_object
 %                       .PosGeometryCalib: size of set_object
 %                       .NbBuiltin: nbre of functions always displayed in transform_fct menu
 %          .Object: cell array of structures representing the current projection objects, as produced by 'set_object.m'={[]} by default
 %          .NewSeries: =0/1 flag telling whether a new field series has been opened
@@ -215,5 +215,5 @@
 end
 
 %% load the list of previously browsed files in menus Open, Open_1 and transform_fct
  dir_perso=prefdir; % path to the directory .matlab containing the personal data of the current user
  profil_perso=fullfile(dir_perso,'uvmat_perso.mat');% personal data file uvmat_perso.mat' in .matlab
@@ -240,8 +240,8 @@
  end
 transform_menu=[transform_menu;{'more...'}];%append the option more.. to the menu
-set(handles.transform_fct,'String',transform_menu)% display the menu of transform fcts
-set(handles.transform_fct,'UserData',path_list)% store the corresponding list of path in UserData of uicontrol transform_fct
-set(handles.path_transform,'String','')
-set(handles.path_transform,'UserData',[])
+set(handles.TransformName,'String',transform_menu)% display the menu of transform fcts
+set(handles.TransformName,'UserData',path_list)% store the corresponding list of path in UserData of uicontrol transform_fct
+set(handles.TransformPath,'String','')
+set(handles.TransformPath,'UserData',[])
 
 %% case of an input argument for uvmat
@@ -973,5 +973,5 @@
         set(handles.pxcm,'String','')
         set(handles.pycm,'String','')
-        set(handles.transform_fct,'Value',1); %  no transform by default
+        set(handles.TransformName,'Value',1); %  no transform by default
     else
         if (isfield(GeometryCalib,'R')&& ~isequal(GeometryCalib.R(2,1),0) && ~isequal(GeometryCalib.R(1,2),0)) ||...
@@ -986,5 +986,5 @@
         end
         if ~get(handles.CheckFixLimits,'Value')
-            set(handles.transform_fct,'Value',3); % phys transform by default if fixedLimits is off
+            set(handles.TransformName,'Value',3); % phys transform by default if fixedLimits is off
         end
         if isfield(GeometryCalib,'SliceCoord')            
@@ -1108,9 +1108,9 @@
 
 %% apply the effect of the transform fct and view the field  
-transform=get(handles.path_transform,'UserData');
+transform=get(handles.TransformPath,'UserData');
 if index==2 && (~isa(transform,'function_handle')||nargin(transform)<3)
-    set(handles.transform_fct,'value',2); % set transform to sub_field if the current fct doe not accept two input fields
-end
-transform_fct_Callback([],[],handles)
+    set(handles.TransformName,'value',2); % set transform to sub_field if the current fct doe not accept two input fields
+end
+TransformName_Callback([],[],handles)
 mask_test=get(handles.CheckMask,'value');
 if mask_test
@@ -1413,8 +1413,8 @@
         end
         %px to phys or other transform on field
-         menu_transform=get(handles.transform_fct,'String');
-        choice_value=get(handles.transform_fct,'Value');
+         menu_transform=get(handles.TransformName,'String');
+        choice_value=get(handles.TransformName,'Value');
         transform_name=menu_transform{choice_value};%name of the transform fct  given by the menu 'transform_fct'
-        transform=get(handles.path_transform,'UserData');
+        transform=get(handles.TransformPath,'UserData');
         if  ~isequal(transform_name,'') && ~isequal(transform_name,'px')
             if isfield(UvData,'XmlData') && isfield(UvData.XmlData{1},'GeometryCalib')%use geometry calib recorded from the ImaDoc xml file as first priority
@@ -1947,5 +1947,5 @@
 
 %px to phys or other transform on field
-transform=get(handles.path_transform,'UserData');
+transform=get(handles.TransformPath,'UserData');
 if  ~isempty(transform)
     if isfield(UvData,'XmlData') && numel(UvData.XmlData)>=index %use geometry calib recorded from the ImaDoc xml file as first priority
@@ -2420,5 +2420,5 @@
 
 %% apply coordinate transform or other user fct
-transform=get(handles.path_transform,'UserData');
+transform=get(handles.TransformPath,'UserData');
 if isempty(transform)
     UvData.Field=Field{1};
@@ -2432,5 +2432,5 @@
         end
     end
-    transform=get(handles.path_transform,'UserData');
+    transform=get(handles.TransformPath,'UserData');
     switch nargin(transform)
         case 4
@@ -2999,8 +2999,8 @@
     end 
     set(handles.uvmat,'UserData',UvData);
-    transform_fct_list=get(handles.transform_fct,'String');
-    transform_fct=transform_fct_list(get(handles.transform_fct,'Value'));
+    transform_fct_list=get(handles.TransformName,'String');
+    transform_fct=transform_fct_list(get(handles.TransformName,'Value'));
     if strcmp(transform_fct,'sub_field')
-        set(handles.transform_fct,'Value',1)%suppress the sub_field transform
+        set(handles.TransformName,'Value',1)%suppress the sub_field transform
         transform_fct_Callback(hObject, eventdata, handles); 
     else
@@ -3301,8 +3301,8 @@
             UvData.FileType{2}=UvData.FileType{1};
             UvData.XmlData{2}= UvData.XmlData{1};
-            transform=get(handles.path_transform,'UserData');
+            transform=get(handles.TransformPath,'UserData');
              if (~isa(transform,'function_handle')||nargin(transform)<3)
                 set(handles.uvmat,'UserData',UvData)
-                set(handles.transform_fct,'value',2); % set transform fct to 'sub_field' if the current fct does not accept two input fields
+                set(handles.TransformName,'value',2); % set transform fct to 'sub_field' if the current fct does not accept two input fields
                 transform_fct_Callback(hObject, eventdata, handles)% activate transform_fct_Callback and refresh current plot
                  check_refresh=0;
@@ -3400,8 +3400,8 @@
      UvData.XmlData{2}= UvData.XmlData{1};
      set(handles.SubField,'Value',1)
-     transform=get(handles.path_transform,'UserData');
+     transform=get(handles.TransformPath,'UserData');
      if (~isa(transform,'function_handle')||nargin(transform)<3)
         set(handles.uvmat,'UserData',UvData)
-        set(handles.transform_fct,'value',2); % set transform fct to 'sub_field' if the current fct does not accept two input fields
+        set(handles.TransformName,'value',2); % set transform fct to 'sub_field' if the current fct does not accept two input fields
         transform_fct_Callback(hObject, eventdata, handles)% activate transform_fct_Callback and refresh current plot
      else
@@ -3606,16 +3606,16 @@
 %------------------------------------------------------------------
 %-------------------------------------------------------------
-% --- Executes on selection change in transform_fct.
-
-function transform_fct_Callback(hObject, eventdata, handles)
+% --- Executes on selection change in TransformName.
+
+function TransformName_Callback(hObject, eventdata, handles)
 %-------------------------------------------------------------
 UvData=get(handles.uvmat,'UserData');
-menu=get(handles.transform_fct,'String');refresh
-ichoice=get(handles.transform_fct,'Value');%item number in the menu
+menu=get(handles.TransformName,'String');refresh
+ichoice=get(handles.TransformName,'Value');%item number in the menu
 transform_name=menu{ichoice};% choice of the transform fct
-list_path=get(handles.transform_fct,'UserData');
+list_path=get(handles.TransformName,'UserData');
 
 %% add a new item to the menu if the option 'more...' has been selected
-prev_path=fullfile(get(handles.path_transform,'String'));
+prev_path=fullfile(get(handles.TransformPath,'String'));
 if ~exist(prev_path,'dir')
     prev_path=fullfile(fileparts(which('uvmat')),'transform_field');
@@ -3641,6 +3641,6 @@
     end
     list_path{ichoice}=PathName;%update the list fo fct paths
-    set(handles.transform_fct,'String',menu)
-    set(handles.transform_fct,'Value',ichoice)
+    set(handles.TransformName,'String',menu)
+    set(handles.TransformName,'Value',ichoice)
     
     % save the new menu in the personal file 'uvmat_perso.mat'
@@ -3672,11 +3672,11 @@
     cd(current_dir)
 end
-set(handles.path_transform,'String',list_path{ichoice})
-set(handles.path_transform,'UserData',transform_handle)
-set(handles.transform_fct,'UserData',list_path)
-
-%% update the ToolTip string of the menu transform_fct with the first line of the selected fct file
+set(handles.TransformPath,'String',list_path{ichoice})
+set(handles.TransformPath,'UserData',transform_handle)
+set(handles.TransformName,'UserData',list_path)
+
+%% update the ToolTip string of the menu TransformName with the first line of the selected fct file
 if isempty(list_path{ichoice})% case of no selected fct
-    set(handles.transform_fct,'ToolTipString','transform_fct:choose a transform function')
+    set(handles.TransformName,'ToolTipString','transform_fct:choose a transform function')
 else
     try
@@ -3684,5 +3684,5 @@
         InputText=textscan(fid,'%s',1,'delimiter','\n');
         fclose(fid)
-        set(handles.transform_fct,'ToolTipString',['transform_fct: ' InputText{1}{1}])% put the first line of the selected function as tooltip help
+        set(handles.TransformName,'ToolTipString',['transform_fct: ' InputText{1}{1}])% put the first line of the selected function as tooltip help
     end
 end
@@ -5066,6 +5066,6 @@
 FileName=[fullfile(RootPath,SubDir,RootFile) FileIndex FileExt];
 UvData=get(handles.uvmat,'UserData');
-% CoordList=get(handles.transform_fct,'String');
-% val=get(handles.transform_fct,'Value');
+% CoordList=get(handles.TransformName,'String');
+% val=get(handles.TransformName,'Value');
 set_grid(FileName,UvData.Field);% call the set_object interface
 
@@ -5089,5 +5089,4 @@
 function MenuSeries_Callback(hObject, eventdata, handles)
 %------------------------------------------------------------------------
-series; %first display of the GUI to fill waiting time
 [RootPath,SubDir,RootFile,FileIndex,FileExt]=read_file_boxes(handles);
 Param.FileName=[fullfile(RootPath,SubDir,RootFile) FileIndex FileExt];%first input file name
@@ -5128,6 +5127,6 @@
 end
 Param.index_fields_1=find(strcmp(FieldName_1,Param.list_fields_1));% selected string index
-Param.transform_str=get(handles.transform_fct,'String');
-Param.transform_val=get(handles.transform_fct,'Value');
+TransformList=get(handles.TransformName,'String');
+Param.TransformName=TransformList{get(handles.TransformName,'Value')};
 Param.Coord_x_str=get(handles.Coord_x,'String');
 Param.Coord_x_val=get(handles.Coord_x,'Value');
@@ -5165,2 +5164,12 @@
 % --- Executes on button press in CheckColorBar.
 function CheckColorBar_Callback(hObject, eventdata, handles)
+
+
+
+function TransformPath_Callback(hObject, eventdata, handles)
+% hObject    handle to TransformPath (see GCBO)
+% eventdata  reserved - to be defined in a future version of MATLAB
+% handles    structure with handles and user data (see GUIDATA)
+
+% Hints: get(hObject,'String') returns contents of TransformPath as text
+%        str2double(get(hObject,'String')) returns contents of TransformPath as a double
@@ -34,5 +34,5 @@
 %                       .PosSetObject: position of set_object
 %                       .PosGeometryCalib: size of set_object
-%                       .NbBuiltin: nbre of functions always displayed in transform_fct menu
+%                       .NbBuiltin: nbre of functions always displayed in TransformName menu
 %          .Object: cell array of structures representing the current projection objects, as produced by 'set_object.m'={[]} by default
 %          .NewSeries: =0/1 flag telling whether a new field series has been opened
@@ -215,5 +215,5 @@
 end
 
-%% load the list of previously browsed files in menus Open, Open_1 and transform_fct
+%% load the list of previously browsed files in menus Open, Open_1 and TransformName
  dir_perso=prefdir; % path to the directory .matlab containing the personal data of the current user
  profil_perso=fullfile(dir_perso,'uvmat_perso.mat');% personal data file uvmat_perso.mat' in .matlab
